
-- Description des librairies a inclure 
-- pour la synthese VHDL

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

-- Description des entrees/sorties 
-- du circuit : in (entree) et out (sortie)

-- Cet operateur realise la fonction
-- out = in default default_val

entity defaultlogic is
    Port ( in_val : in std_logic;
           in_str : in std_logic;
           default_val : in std_logic;
           default_str : in std_logic;
			  out_val : out std_logic;
           out_str : out std_logic);
end defaultlogic;

-- Description du comportement du circuit
-- relativement a l'entite ci-dessus

architecture behavioral of defaultlogic is

-- Debut de l'architecture

begin

-- le strobe du signal de sortie est un
-- ou entre les strobes des deux entrees
-- voir le fonctionnement de l'operateur default

out_str <= in_str or default_str;

-- en VHDL, un processus va etre executee lorsqu'une
-- de ses entrees est modifie, c'est a dire que le
-- signal out varie si 
--  	le strobe du signal in varie (place au signal default)
--		le signal in_val varie
--		le signal default_val varie

process(in_str, in_val,default_val)
begin

-- si le strobe du signal in est actif alors out prend
-- la valeur de in sinon in prend la valeur de default_val

if (in_str = '1') then  out_val <= in_val; else
								out_val <= default_val;
end if;

end process;

end behavioral;
